Stan Math Library: stan/math/rev/mat/fun/multiply.hpp File Reference

| Stan Math Library 2.10.0 reverse mode automatic differentiation

- Main Page
- Modules
- Namespaces
- Classes
- Files

- File List
- File Members

Namespaces | Functions
multiply.hpp File Reference
`#include <stan/math/rev/core.hpp>`
`#include <stan/math/rev/mat/fun/Eigen_NumTraits.hpp>`
`#include <stan/math/rev/mat/fun/typedefs.hpp>`
`#include <stan/math/prim/mat/fun/Eigen.hpp>`
`#include <stan/math/prim/mat/fun/typedefs.hpp>`
`#include <stan/math/prim/mat/err/check_multiplicable.hpp>`
`#include <stan/math/rev/mat/fun/to_var.hpp>`
`#include <stan/math/rev/mat/fun/dot_product.hpp>`
`#include <boost/utility/enable_if.hpp>`
`#include <boost/type_traits.hpp>`
`#include <boost/math/tools/promotion.hpp>`
`#include <stdexcept>`

Go to the source code of this file.

## Namespaces
| stan
| stan::math
| Matrices and templated mathematical functions.

## Functions
template<typename T1 , typename T2 >
boost::enable_if_c< (boost::is_scalar< T1 >::value||boost::is_same< T1, var >::value)&&(boost::is_scalar< T2 >::value||boost::is_same< T2, var >::value), typename boost::math::tools::promote_args< T1, T2 >::type >::type | stan::math::multiply (const T1 &v, const T2 &c)
| Return the product of two scalars. More...
template<typename T1 , typename T2 , int R2, int C2>
Eigen::Matrix< var, R2, C2 > | stan::math::multiply (const T1 &c, const Eigen::Matrix< T2, R2, C2 > &m)
| Return the product of scalar and matrix. More...
template<typename T1 , int R1, int C1, typename T2 >
Eigen::Matrix< var, R1, C1 > | stan::math::multiply (const Eigen::Matrix< T1, R1, C1 > &m, const T2 &c)
| Return the product of scalar and matrix. More...
template<typename T1 , int R1, int C1, typename T2 , int R2, int C2>
boost::enable_if_c< boost::is_same< T1, var >::value||boost::is_same< T2, var >::value, Eigen::Matrix< var, R1, C2 > >::type | stan::math::multiply (const Eigen::Matrix< T1, R1, C1 > &m1, const Eigen::Matrix< T2, R2, C2 > &m2)
| Return the product of the specified matrices. More...
template<typename T1 , int C1, typename T2 , int R2>
boost::enable_if_c< boost::is_same< T1, var >::value||boost::is_same< T2, var >::value, var >::type | stan::math::multiply (const Eigen::Matrix< T1, 1, C1 > &rv, const Eigen::Matrix< T2, R2, 1 > &v)
| Return the scalar product of the specified row vector and specified column vector. More...

[ Stan Home Page ] © 2011–2016, Stan Development Team.